@@ -25,7 +25,7 @@ from rednotebook.util import utils
 from rednotebook import info
 from rednotebook.util import filesystem
 from rednotebook.util import markup
-from rednotebook.gui.imports import ImportAssistant
+#from rednotebook.gui.imports import ImportAssistant
 
 
 class MainMenuBar(object):
@@ -118,9 +118,9 @@ class MainMenuBar(object):
 
             ('Edit', None, _('_Edit'), None, None, self.on_edit_menu_activate),
             ('Undo', gtk.STOCK_UNDO, None,
-                '<Ctrl>z', _('Undo text edits or category entry deletions'), self.on_undo),
+                '<Ctrl>z', _('Undo text or tag edits'), self.on_undo),
             ('Redo', gtk.STOCK_REDO, None,
-                '<Ctrl>y', _('Redo text edits or category entry additions'), self.on_redo),
+                '<Ctrl>y', _('Redo text or tag edits'), self.on_redo),
             ('Cut', gtk.STOCK_CUT, None,
                 '', None, self.on_cut_menu_item_activate),
             ('Copy', gtk.STOCK_COPY, None,
@@ -138,7 +138,7 @@ class MainMenuBar(object):
             ('Help', gtk.STOCK_HELP, _('Contents'),
                 '<Ctrl>h', _('Open the RedNotebook documentation'), self.on_help_menu_item_activate),
             ('OnlineHelp', None, _('Get Help Online'),
-                None, _('Visit the RedNotebook forum'), self.on_online_help),
+                None, _('Browse answered questions or ask a new one'), self.on_online_help),
             ('Translate', None, _('Translate RedNotebook'),
                 None, _('Connect to the Launchpad website to help translate RedNotebook'),
                 self.on_translate),
@@ -222,15 +222,13 @@ class MainMenuBar(object):
         '''
         Change to search page and put the cursor into the search box
         '''
-        self.main_window.search_notebook.set_current_page(0)
         self.main_window.search_box.entry.grab_focus()
 
     def on_options_menuitem_activate(self, widget):
         self.main_window.options_manager.on_options_dialog()
 
-
     def on_backup_activate(self, widget):
-        self.journal.backup_contents(backup_file=self.main_window.get_backup_file())
+        self.journal.archiver.backup()
 
     def on_import_menu_item_activate(self, widget):
         assistant = ImportAssistant(self.journal)
@@ -238,7 +236,6 @@ class MainMenuBar(object):
 
     def on_export_menu_item_activate(self, widget):
         self.journal.save_old_day()
-
         self.main_window.export_assistant.run()
 
     def on_statistics_menu_item_activate(self, widget):
@@ -253,7 +250,7 @@ class MainMenuBar(object):
         utils.show_html_in_browser(html, os.path.join(temp_dir, 'help.html'))
 
     def on_online_help(self, widget):
-        webbrowser.open(info.forum_url)
+        webbrowser.open(info.answers_url)
 
     def on_translate(self, widget):
         webbrowser.open(info.translation_url)
