@@ -20,18 +20,26 @@
 from __future__ import with_statement
 
 import os
-import zipfile
+import imp
+import sys
+import locale
 import subprocess
 import logging
 import codecs
 import webbrowser
 from glob import glob
 
+ENCODING = sys.getfilesystemencoding() or locale.getlocale()[1] or 'UTF-8'
+
+
+def get_unicode_path(path):
+    return unicode(path, ENCODING)
+
+def get_utf8_path(path):
+    return path.encode(ENCODING)
 
 
 #from http://www.py2exe.org/index.cgi/HowToDetermineIfRunningFromExe
-import imp, os, sys
-
 def main_is_frozen():
     return (hasattr(sys, "frozen") or # new py2exe
         hasattr(sys, "importers") # old py2exe
@@ -41,7 +49,7 @@ def get_main_dir():
     if main_is_frozen():
         return os.path.dirname(sys.executable)
     return os.path.dirname(sys.argv[0])
-#--------------------------------------------------------------------------------------------------------
+#------------------------------------------------------------------------------
 
 
 if not main_is_frozen():
@@ -50,14 +58,14 @@ if not main_is_frozen():
 else:
     app_dir = get_main_dir()
 
-
+app_dir = get_unicode_path(app_dir)
 
 image_dir = os.path.join(app_dir, 'images')
 frame_icon_dir = os.path.join(image_dir, 'rednotebook-icon')
 files_dir = os.path.join(app_dir, 'files')
-gui_dir = os.path.join(app_dir, 'gui')
+locale_dir = os.path.join(app_dir, 'i18n')
 
-user_home_dir = os.path.expanduser('~')
+user_home_dir = get_unicode_path(os.path.expanduser('~'))
 
 
 class Filenames(dict):
@@ -67,7 +75,7 @@ class Filenames(dict):
     def __init__(self, config):
         for key, value in globals().items():
             # Exclude "get_main_dir()"
-            if key.lower().endswith('dir') and type(value) is str:
+            if key.lower().endswith('dir') and isinstance(value, basestring):
                 value = os.path.abspath(value)
                 self[key] = value
                 setattr(self, key, value)
@@ -78,12 +86,9 @@ class Filenames(dict):
 
         self.data_dir = self.default_data_dir
 
-        # Is this the first run of RedNotebook?
-        self.is_first_start = not os.path.exists(self.journal_user_dir)
-
         # Assert that all dirs and files are in place so that logging can take start
         make_directories([self.journal_user_dir, self.data_dir, self.template_dir,
-                        self.temp_dir])
+                          self.temp_dir])
         make_files([(self.config_file, ''), (self.log_file, '')])
 
         self.last_pic_dir = self.user_home_dir
@@ -169,20 +174,15 @@ def read_file(filename):
 
 def write_file(filename, content):
     assert os.path.isabs(filename)
-    #print 'CONTENT', type(content), repr(content)
-    #if not type(content) == unicode:
-        # Turn content into unicode string
-    #    content = content.decode('utf-8')
     try:
         with codecs.open(filename, 'wb', errors='replace', encoding='utf-8') as file:
-        #with open(filename, 'wb') as file:
             file.write(content)
     except IOError, e:
         logging.error('Error while writing to "%s": %s' % (filename, e))
 
 
 def make_directory(dir):
-    if not os.path.exists(dir):
+    if not os.path.isdir(dir):
         os.makedirs(dir)
 
 def make_directories(dirs):
@@ -190,7 +190,7 @@ def make_directories(dirs):
         make_directory(dir)
 
 def make_file(file, content=''):
-    if not os.path.exists(file):
+    if not os.path.isfile(file):
         write_file(file, content)
 
 def make_files(file_content_pairs):
@@ -222,22 +222,9 @@ def get_relative_path(from_dir, to_dir):
     else:
         return to_dir
 
-def write_archive(archive_file_name, files, base_dir='', arc_base_dir=''):
-    """
-    use base_dir for relative filenames, in case you don't
-    want your archive to contain '/home/...'
-    """
-    archive = zipfile.ZipFile(archive_file_name, "w")
-    for file in files:
-        archive.write(file, os.path.join(arc_base_dir, file[len(base_dir):]))
-    archive.close()
-
 def get_icons():
     return glob(os.path.join(frame_icon_dir, '*.png'))
 
-def uri_is_local(uri):
-    return uri.startswith('file://')
-
 
 def get_journal_title(dir):
     '''
@@ -270,7 +257,7 @@ def get_platform_info():
     for name, object, value in lib_values:
         try:
             names_values.append((name, getattr(object, value)))
-        except AttributeError, err:
+        except AttributeError:
             logging.info('%s could not be determined' % name)
 
     vals = ['%s: %s' % (name, val) for name, val in names_values]
@@ -289,6 +276,11 @@ def system_call(args):
 def get_local_url(url):
     '''
     Sanitize url, make it absolute and normalize it, then add file://(/) scheme
+
+    Links and images only work in webkit on windows if the files have
+    file:/// (3 slashes) in front of the filename.
+    Strangely when clicking a link that has two slashes (file://C:\file.ext),
+    webkit returns the path file://C/file.ext .
     '''
     orig_url = url
     if url.startswith('file:///') and sys.platform == 'win32':
@@ -297,8 +289,6 @@ def get_local_url(url):
         url = url.replace('file://', '')
     url = os.path.normpath(url)
 
-    import urllib
-    url = urllib.unquote(url).decode('utf-8')
     scheme = 'file:///' if sys.platform == 'win32' else 'file://'
     url = scheme + url
     logging.debug('Transformed local URI %s to %s' % (orig_url, url))
@@ -313,41 +303,47 @@ def open_url_in_browser(url):
         logging.exception('Failed to open web browser')
 
 
+def unquote_url(url):
+    import urllib
+    return urllib.unquote(url).decode('utf-8')
+
+
 def open_url(url):
     '''
     Opens a file with the platform's preferred method
     '''
-    if url.startswith('http'):
+    if url.lower().startswith('http'):
         open_url_in_browser(url)
         return
 
     # Try opening the file locally
     if sys.platform == 'win32':
         try:
-            if uri_is_local(url):
+            url = unquote_url(url)
+            if url.startswith(u'file:') or os.path.exists(url):
                 url = get_local_url(url)
             logging.info('Trying to open %s with "os.startfile"' % url)
             # os.startfile is only available on windows
             os.startfile(url)
             return
-        except (WindowsError, OSError):
+        except OSError:
             logging.exception('Opening %s with "os.startfile" failed' % url)
+            return
 
     elif sys.platform == 'darwin':
         try:
             logging.info('Trying to open %s with "open"' % url)
             system_call(['open', url])
             return
-        except OSError, subprocess.CalledProcessError:
+        except (OSError, subprocess.CalledProcessError):
             logging.exception('Opening %s with "open" failed' % url)
 
     else:
         try:
-            subprocess.check_call(['xdg-open', '--version'])
             logging.info( 'Trying to open %s with xdg-open' % url)
             system_call(['xdg-open', url])
             return
-        except OSError, subprocess.CalledProcessError:
+        except (OSError, subprocess.CalledProcessError):
             logging.exception('Opening %s with xdg-open failed' % url)
 
     # If everything failed, try the webbrowser
